﻿////////////////////////////////////////////////////////////////////////////////
//
//  SvgCircleElement.cs - This file is part of Svg2Xaml.
//
//    Copyright (C) 2009,2011 Boris Richter <himself@boris-richter.net>
//
//  --------------------------------------------------------------------------
//
//  Svg2Xaml is free software: you can redistribute it and/or modify it under 
//  the terms of the GNU Lesser General Public License as published by the 
//  Free Software Foundation, either version 3 of the License, or (at your 
//  option) any later version.
//
//  Svg2Xaml is distributed in the hope that it will be useful, but WITHOUT 
//  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
//  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public 
//  License for more details.
//  
//  You should have received a copy of the GNU Lesser General Public License 
//  along with Svg2Xaml. If not, see <http://www.gnu.org/licenses/>.
//
//  --------------------------------------------------------------------------
//
//  $LastChangedRevision: 69861 $
//  $LastChangedDate: 2011-09-18 15:49:23 -0700 (周日, 18 九月 2011) $
//  $LastChangedBy: unknown $
//
////////////////////////////////////////////////////////////////////////////////
using System.Windows;
using System.Windows.Media;
using System.Xml.Linq;

namespace Svg2Xaml
{
  
  //****************************************************************************
  /// <summary>
  ///   Represents an &lt;circle&gt; element.
  /// </summary>
  class SvgCircleElement
    : SvgDrawableBaseElement
  {
    //==========================================================================
    /// <summary>
    ///   The x-coordinate of the circle's center.
    /// </summary>
    public readonly SvgCoordinate CenterX = new SvgCoordinate(0);

    //==========================================================================
    /// <summary>
    ///   The y-coordinate of the circle's center.
    /// </summary>
    public readonly SvgCoordinate CenterY = new SvgCoordinate(0);

    //==========================================================================
    /// <summary>
    ///   The circle's radius.
    /// </summary>
    public readonly SvgLength Radius = new SvgLength(0);

    //==========================================================================
    public SvgCircleElement(SvgDocument document, SvgBaseElement parent, XElement circleElement)
      : base(document, parent, circleElement)
    {
      XAttribute cx_attribute = circleElement.Attribute("cx");
      if(cx_attribute != null)
        CenterX = SvgCoordinate.Parse(cx_attribute.Value);

      XAttribute cy_attribute = circleElement.Attribute("cy");
      if(cy_attribute != null)
        CenterY = SvgCoordinate.Parse(cy_attribute.Value);

      XAttribute r_attribute = circleElement.Attribute("r");
      if(r_attribute != null)
        Radius = SvgLength.Parse(r_attribute.Value);
    }

    //==========================================================================
    public override Geometry GetBaseGeometry()
    {
      return new EllipseGeometry(new Point(CenterX.ToDouble(), CenterY.ToDouble()), 
                                 Radius.ToDouble(), Radius.ToDouble());
    }

  } // class SvgCircleElement

}
